@@ -60,13 +60,13 @@ var Go = internal.Register(MustNewLexer(
 
 var goTemplateRules = Rules{
 	"root": {
+		{`{{(- )?/\*(.|\n)*?\*/( -)?}}`, CommentMultiline, nil},
 		{`{{[-]?`, CommentPreproc, Push("template")},
 		{`[^{]+`, Other, nil},
 		{`{`, Other, nil},
 	},
 	"template": {
 		{`[-]?}}`, CommentPreproc, Pop(1)},
-		{`/\*.*?\*/`, Comment, nil},
 		{`(?=}})`, CommentPreproc, Pop(1)}, // Terminate the pipeline
 		{`\(`, Operator, Push("subexpression")},
 		{`"(\\\\|\\"|[^"])*"`, LiteralString, nil},
@@ -80,19 +80,19 @@ var goTemplateRules = Rules{
 		{`\s+`, Whitespace, nil},
 		{`\(`, Operator, Push("subexpression")},
 		{`(range|if|else|while|with|template|end|true|false|nil|and|call|html|index|js|len|not|or|print|printf|println|urlquery|eq|ne|lt|le|gt|ge)\b`, Keyword, nil},
-		{`\||:=`, Operator, nil},
+		{`\||:?=|,`, Operator, nil},
 		{`[$]?[^\W\d]\w*`, NameOther, nil},
 		{`[$]?\.(?:[^\W\d]\w*)?`, NameAttribute, nil},
 		{`"(\\\\|\\"|[^"])*"`, LiteralString, nil},
-		{`\d+i`, LiteralNumber, nil},
-		{`\d+\.\d*([Ee][-+]\d+)?i`, LiteralNumber, nil},
+		{`-?\d+i`, LiteralNumber, nil},
+		{`-?\d+\.\d*([Ee][-+]\d+)?i`, LiteralNumber, nil},
 		{`\.\d+([Ee][-+]\d+)?i`, LiteralNumber, nil},
-		{`\d+[Ee][-+]\d+i`, LiteralNumber, nil},
-		{`\d+(\.\d+[eE][+\-]?\d+|\.\d*|[eE][+\-]?\d+)`, LiteralNumberFloat, nil},
-		{`\.\d+([eE][+\-]?\d+)?`, LiteralNumberFloat, nil},
-		{`0[0-7]+`, LiteralNumberOct, nil},
-		{`0[xX][0-9a-fA-F]+`, LiteralNumberHex, nil},
-		{`(0|[1-9][0-9]*)`, LiteralNumberInteger, nil},
+		{`-?\d+[Ee][-+]\d+i`, LiteralNumber, nil},
+		{`-?\d+(\.\d+[eE][+\-]?\d+|\.\d*|[eE][+\-]?\d+)`, LiteralNumberFloat, nil},
+		{`-?\.\d+([eE][+\-]?\d+)?`, LiteralNumberFloat, nil},
+		{`-?0[0-7]+`, LiteralNumberOct, nil},
+		{`-?0[xX][0-9a-fA-F]+`, LiteralNumberHex, nil},
+		{`-?(0|[1-9][0-9]*)`, LiteralNumberInteger, nil},
 		{`'(\\['"\\abfnrtv]|\\x[0-9a-fA-F]{2}|\\[0-7]{1,3}|\\u[0-9a-fA-F]{4}|\\U[0-9a-fA-F]{8}|[^\\])'`, LiteralStringChar, nil},
 		{"`[^`]*`", LiteralString, nil},
 	},
